@@ -6,7 +6,7 @@ use warnings;
 
 BEGIN {
 	$Type::Library::AUTHORITY = 'cpan:TOBYINK';
-	$Type::Library::VERSION   = '1.001_016';
+	$Type::Library::VERSION   = '1.003_000';
 }
 
 use Eval::TypeTiny qw< eval_closure >;
@@ -536,6 +536,11 @@ assume that the C<Types::Mine> library defines types C<Number> and C<String>.
    #
    use Types::Mine qw( :types );
    
+   # Exports "coerce_String" and "coerce_Number", as well as any other
+   # coercions
+   #
+   use Types::Mine qw( :coercions );
+   
    # Exports a sub "is_String" so that "is_String($foo)" is equivalent
    # to "String->check($foo)".
    #
