@@ -10,7 +10,7 @@ BEGIN {
 
 BEGIN {
 	$Types::Common::Numeric::AUTHORITY = 'cpan:TOBYINK';
-	$Types::Common::Numeric::VERSION   = '1.001_016';
+	$Types::Common::Numeric::VERSION   = '1.003_000';
 }
 
 use Type::Library -base, -declare => qw(
@@ -44,7 +44,8 @@ $meta->add_type(
 
 my ($pos_int, $posz_int);
 if (Type::Tiny::_USE_XS) {
-	$pos_int  = Type::Tiny::XS::get_coderef_for('PositiveInt');
+	$pos_int  = Type::Tiny::XS::get_coderef_for('PositiveInt')
+		if Type::Tiny::XS->VERSION >= 0.013; # fixed bug with "00"
 	$posz_int = Type::Tiny::XS::get_coderef_for('PositiveOrZeroInt');
 }
 
